'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

exports.pageNotFoundError = pageNotFoundError;
exports.normalizePagePath = normalizePagePath;
exports.getPagePath = getPagePath;

var _path = require('path');

var _constants = require('../lib/constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function pageNotFoundError(page) {
  var err = new Error('Cannot find module for page: ' + page);
  err.code = 'ENOENT';
  return err;
}

function normalizePagePath(page) {
  // If the page is `/` we need to append `/index`, otherwise the returned directory root will be bundles instead of pages
  if (page === '/') {
    page = '/index';
  }

  // Resolve on anything that doesn't start with `/`
  if (page[0] !== '/') {
    page = '/' + page;
  }

  // Throw when using ../ etc in the pathname
  var resolvedPage = _path.posix.normalize(page);
  if (page !== resolvedPage) {
    throw new Error('Requested and resolved page mismatch');
  }

  return page;
}

function getPagePath(page, _ref) {
  var dir = _ref.dir,
      dist = _ref.dist;

  var serverBuildPath = (0, _path.join)(dir, dist, 'dist');
  var pagesManifest = require((0, _path.join)(serverBuildPath, _constants.PAGES_MANIFEST));

  try {
    page = normalizePagePath(page);
  } catch (err) {
    console.error(err);
    throw pageNotFoundError(page);
  }

  if (!pagesManifest[page]) {
    throw pageNotFoundError(page);
  }

  return (0, _path.join)(serverBuildPath, pagesManifest[page]);
}

exports.default = function () {
  var _ref3 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(page, _ref2) {
    var dir = _ref2.dir,
        dist = _ref2.dist;
    var pagePath;
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            pagePath = getPagePath(page, { dir: dir, dist: dist });
            return _context.abrupt('return', require(pagePath));

          case 2:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  function requirePage(_x, _x2) {
    return _ref3.apply(this, arguments);
  }

  return requirePage;
}();